.. currentmodule:: sardana.sardanameta

:mod:`~sardana.pool.sardanameta`
====================================

.. automodule:: sardana.sardanameta

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`SardanaLibrary`
    * :class:`SardanaClass`

SardanaLibrary
---------------

.. inheritance-diagram:: SardanaLibrary
    :parts: 1
    
.. autoclass:: SardanaLibrary
    :inherited-members:
    :members:
    :undoc-members:
    
SardanaClass
-------------

.. inheritance-diagram:: SardanaClass
    :parts: 1
    
.. autoclass:: SardanaClass
    :inherited-members:
    :members:
    :undoc-members:
